<?php
/**
 * Theme Options.
 *
 * @package OMag
 */

$default = omag_default_theme_options();

/**=========== Option Panel ===========**/
$wp_customize->add_panel(
    'omag_basic_panel', 
    array(
        'title'             => __( 'Theme Options', 'omag' ),
        'priority'          => 200, 
    )
);

/**===== Header Setting - Start ========**/
$wp_customize->add_section(
    'omag_header', 
    array(    
        'title'             => __( 'Header', 'omag' ),
        'panel'             => 'omag_basic_panel', 
    )
);


/**------ Show Top Header -----**/
$wp_customize->add_setting(
    'omag[enable_top_header]',
    array(
        'default'           => $default['enable_top_header'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_top_header]', 
    array(
        'label'             => __( 'Enable Top Header', 'omag' ),
        'section'           => 'omag_header',   
        'settings'          => 'omag[enable_top_header]',     
        'type'              => 'checkbox',
    )
);


/**------- Show Date -------**/
$wp_customize->add_setting(
    'omag[enable_date]',
    array(
        'default'           => $default['enable_date'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_date]', 
    array(
        'label'             => __( 'Enable Date (Top Left)', 'omag' ),
        'section'           => 'omag_header',   
        'settings'          => 'omag[enable_date]',     
        'type'              => 'checkbox',
        'active_callback'   => 'omag_show_top_header',
    )
);


/**------ Enable Navigation -------**/
$wp_customize->add_setting(
    'omag[enable_top_nav]',
    array(
        'default'           => $default['enable_top_nav'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_top_nav]', 
    array(
        'label'             => __( 'Enable Top Nav (Top Left)', 'omag' ),
        'section'           => 'omag_header',   
        'settings'          => 'omag[enable_top_nav]',     
        'type'              => 'checkbox',
        'active_callback'   => 'omag_show_top_header',
    )
);


/*------ Social Media -------*/
$wp_customize->add_setting(
    'omag[enable_social_top]',
    array(
        'default'           => $default['enable_social_top'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_social_top]', 
    array(
        'label'             => __( 'Enable Social Media (Top Right)', 'omag' ),
        'section'           => 'omag_header',   
        'settings'          => 'omag[enable_social_top]',     
        'type'              => 'checkbox',
        'active_callback'   => 'omag_show_top_header',
    )
);


/**------ Show Home Icon --------**/
$wp_customize->add_setting(
    'omag[enable_home_icon]',
    array(
        'default'           => $default['enable_home_icon'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_home_icon]', 
    array(
        'label'             => __( 'Enable Home Icon', 'omag' ),
        'section'           => 'omag_header',   
        'settings'          => 'omag[enable_home_icon]',     
        'type'              => 'checkbox',
    )
);


/**-------- Sticky header ------**/
$wp_customize->add_setting(
    'omag[sticky_header]',
    array(
        'default'           => $default['sticky_header'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[sticky_header]', 
    array(
        'label'             => __( 'Enable sticky header', 'omag' ),
        'section'           => 'omag_header',   
        'settings'          => 'omag[sticky_header]',     
        'type'              => 'checkbox',
    )
);
/**===== Header Setting - End =====**/


/**====== Hot News - Start ======**/
$wp_customize->add_section(
    'omag_hot_news', 
    array(    
        'title'             => __( 'Hot News', 'omag' ),
        'panel'             => 'omag_basic_panel', 
    )
);


/**------- Show Hot News ------**/
$wp_customize->add_setting(
    'omag[enable_hot_news]',
    array(
        'default'           => $default['enable_hot_news'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_hot_news]', 
    array(
        'label'             => __( 'Enable Hot News', 'omag' ),
        'section'           => 'omag_hot_news',   
        'settings'          => 'omag[enable_hot_news]',     
        'type'              => 'checkbox',
    )
);


/**====== Hot News Title =======**/
$wp_customize->add_setting(
    'omag[hot_news_title]', 
    array(
      'default'           => $default['hot_news_title'],  
      'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control(
    'omag[hot_news_title]', 
        array(
        'label'       => __( 'Title', 'omag' ),    
        'settings'    => 'omag[hot_news_title]',
        'section'     => 'omag_hot_news',
        'type'        => 'text',
        'active_callback' => 'omag_show_hot_news',
    )
);


/**----- Hote News Category ------**/
$wp_customize->add_setting(
    'omag[hot_news_cat]', 
    array(
        'default'           => $default['hot_news_cat'],        
        'sanitize_callback' => 'omag_sanitize_number'
    )
);

$wp_customize->add_control(
    new omag_Customize_Category_Control(
        $wp_customize,
        'omag[hot_news_cat]',
        array(
            'label'         => __( 'Select Category', 'omag'  ),
            'settings'      => 'omag[hot_news_cat]',
            'section'       => 'omag_hot_news',
            'active_callback' => 'omag_show_hot_news',     
        )
    )
);


/**----- Hot News Count -----*/
$wp_customize->add_setting( 'omag[hot_news_count]',
    array(
    'default'           => $default['hot_news_count'],
    'sanitize_callback' => 'omag_sanitize_number_range',
    )
);

$wp_customize->add_control( 'omag[hot_news_count]',
    array(
        'label'             => __( 'Count', 'omag' ),
        'settings'          => 'omag[hot_news_count]',
        'section'           => 'omag_hot_news',
        'type'              => 'number',
        'input_attrs'       => array( 'min' => 1, 'max' => 10, 'step' => 1, 'style' => 'width: 66px;' ),
        'active_callback' => 'omag_show_hot_news',
    )
);


/**==== Slideshow Settings - Start ======**/
$wp_customize->add_section(
    'omag_slideshow', 
    array(    
        'title'             => __( 'Slideshow', 'omag' ),
        'panel'             => 'omag_basic_panel'    
    )
); 

/**----- Enable/Disable Slideshow ------**/
$wp_customize->add_setting(
    'omag[slider_enable]', 
    array(
        'default'           => $default['slider_enable'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[slider_enable]', 
    array(
        'label'             => __( 'Enable Slideshow', 'omag' ),
        'section'           => 'omag_slideshow',   
        'settings'          => 'omag[slider_enable]',     
        'type'              => 'checkbox'
    )
);
  

/**------- Slider Category --------**/
$wp_customize->add_setting(
    'omag[slider_cat]', 
    array(
        'default'           => $default['slider_cat'],        
        'sanitize_callback' => 'omag_sanitize_number'
    )
);

$wp_customize->add_control(
    new omag_Customize_Category_Control(
        $wp_customize,
        'omag[slider_cat]',
        array(
            'label'         => __( 'Select Category', 'omag'  ),
            'settings'      => 'omag[slider_cat]',
            'section'       => 'omag_slideshow',
            'active_callback'   => 'omag_show_slideshow',        
        )
    )
);

/**----- Slider Transition Delay -----**/
$wp_customize->add_setting( 'omag[slider_transition_delay]',
    array(
    'default'           => $default['slider_transition_delay'],
    'sanitize_callback' => 'omag_sanitize_number_range',
    )
);

$wp_customize->add_control( 'omag[slider_transition_delay]',
    array(
        'label'             => __( 'Transition Delay', 'omag' ),
        'description'       => __( 'In second(s)', 'omag' ),
        'settings'          => 'omag[slider_transition_delay]',
        'section'           => 'omag_slideshow',
        'type'              => 'number',
        'input_attrs'       => array( 'min' => 1, 'max' => 10, 'step' => 1, 'style' => 'width: 66px;' ),
        'active_callback'   => 'omag_show_slideshow',
    )
);

/**----- Slider Transition Duration -----**/
$wp_customize->add_setting( 'omag[slider_transition_duration]',
    array(
    'default'           => $default['slider_transition_duration'],
    'sanitize_callback' => 'omag_sanitize_number_range',
    )
);

$wp_customize->add_control( 'omag[slider_transition_duration]',
    array(
    'label'             => __( 'Transition Duration', 'omag' ),
    'description'       => __( 'In second(s)', 'omag' ),
    'settings'          => 'omag[slider_transition_duration]',
    'section'           => 'omag_slideshow',
    'type'              => 'number',
    'input_attrs'       => array( 'min' => 1, 'max' => 10, 'step' => 1, 'style' => 'width: 66px;' ),
    'active_callback'   => 'omag_show_slideshow',
    )
);

/**==== Slider Settings - End ======**/


/**==== Featured News Settings - Start =======**/
$wp_customize->add_section(
    'omag_featured_news', 
    array(    
        'title'             => __( 'Featured News ( Right of Slideshow )', 'omag' ),
        'panel'             => 'omag_basic_panel'    
    )
); 

/*----- Enable/Disable Slideshow --------*/
$wp_customize->add_setting(
    'omag[featured_news_enable]', 
    array(
        'default'           => $default['featured_news_enable'],       
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[featured_news_enable]', 
    array(
        'label'             => __( 'Enable Featured News', 'omag' ),
        'section'           => 'omag_featured_news',   
        'settings'          => 'omag[featured_news_enable]',     
        'type'              => 'checkbox'
    )
);
  

/*------ Featured News Category -------*/
$wp_customize->add_setting(
    'omag[featured_news_cat]', 
    array(
        'default'           => $default['featured_news_cat'],        
        'sanitize_callback' => 'omag_sanitize_number'
    )
);

$wp_customize->add_control(
    new omag_Customize_Category_Control(
        $wp_customize,
        'omag[featured_news_cat]',
        array(
            'label'         => __( 'Select Category', 'omag'  ),
            'settings'      => 'omag[featured_news_cat]',
            'section'       => 'omag_featured_news',
            'active_callback'   => 'omag_show_featured_news',        
        )
    )
);


/**==== Featured News Layout =====**/
$wp_customize->add_setting( 
    'omag[featured_news_layout]',
    array(
        'default'           => $default['featured_news_layout'],
        'sanitize_callback' => 'omag_sanitize_select',
    )
);
$wp_customize->add_control( 'omag[featured_news_layout]',
    array(
        'label'       => esc_html__( 'Select Layout', 'omag'  ),
        'section'     => 'omag_featured_news',   
        'settings'    => 'omag[featured_news_layout]',
        'type'        => 'radio',
        'choices'     => array(
            'primary'     => esc_html__( 'Primary', 'omag'  ),
            'secondary'      => esc_html__( 'Secondary', 'omag'  ),
            ),
        'active_callback' => 'omag_show_featured_news',
    )
);


/**===== Blog Options - Start ======**/
$wp_customize->add_section(
    'omag_blog_options', 
    array(    
        'title'       => __('Blog Options', 'omag' ),
        'panel'       => 'omag_basic_panel'    
    )
);

/**====== Post View =======**/
$wp_customize->add_setting( 
    'omag[post_view]',
    array(
        'default'           => $default['post_view'],
        'sanitize_callback' => 'omag_sanitize_select',
    )
);
$wp_customize->add_control( 'omag[post_view]',
    array(
        'label'       => esc_html__( 'Post View', 'omag'  ),
        'section'     => 'omag_blog_options',   
        'settings'    => 'omag[post_view]',
        'type'        => 'radio',
        'choices'     => array(
            'list'     => esc_html__( 'List', 'omag'  ),
            'grid'      => esc_html__( 'Grid', 'omag'  ),
            )
    )
);


/**====== Enable/Disable - Post Date =======**/
$wp_customize->add_setting(
    'omag[enable_post_date]', 
    array(
        'default'           => $default['enable_post_date'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_post_date]', 
    array(
        'label'       => __('Enable Post Date', 'omag' ),    
        'settings'    => 'omag[enable_post_date]',
        'section'     => 'omag_blog_options',
        'type'        => 'checkbox',
    )
);

/**===== Enable/Disable - Post Author =======**/
$wp_customize->add_setting(
    'omag[enable_post_author]', 
    array(
        'default'           => $default['enable_post_author'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_post_author]', 
    array(
        'label'       => __('Enable Post Author', 'omag' ),    
        'settings'    => 'omag[enable_post_author]',
        'section'     => 'omag_blog_options',
        'type'        => 'checkbox',
    )
);

/**==== Enable/Disable - Post Category =====**/
$wp_customize->add_setting(
    'omag[enable_post_category]', 
    array(
        'default'           => $default['enable_post_category'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_post_category]', 
    array(
        'label'       => __('Enable Post Category', 'omag' ),    
        'settings'    => 'omag[enable_post_category]',
        'section'     => 'omag_blog_options',
        'type'        => 'checkbox',
    )
);

/**====== Enable/Disable - Post Tags =====**/
$wp_customize->add_setting(
    'omag[enable_post_tags]', 
    array(
        'default'           => $default['enable_post_tags'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_post_tags]', 
    array(
        'label'       => __('Enable Post Tags', 'omag' ),    
        'settings'    => 'omag[enable_post_tags]',
        'section'     => 'omag_blog_options',
        'type'        => 'checkbox',
    )
);

/**====== Enable/Disable - Comments Count ======**/
$wp_customize->add_setting(
    'omag[enable_comments_count]', 
    array(
        'default'           => $default['enable_comments_count'],    
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_comments_count]', 
    array(
        'label'       => __('Enable Comments Count', 'omag' ),    
        'settings'    => 'omag[enable_comments_count]',
        'section'     => 'omag_blog_options',
        'type'        => 'checkbox',
    )
);

/**==== Blog Options - End ======**/


/**====== Single Post Settings - Start =====**/

$wp_customize->add_section(
    'omag_single_post', 
    array(    
        'title'       => __('Single Post Settings', 'omag' ),
        'panel'       => 'omag_basic_panel'    
    )
);

/**======= Enable/Disable - Post Date in Single Post =====**/

$wp_customize->add_setting(
    'omag[single_post_date]', 
    array(
        'default'           => $default['single_post_date'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[single_post_date]', 
    array(
        'label'       => __('Enable Post Date', 'omag' ),    
        'settings'    => 'omag[single_post_date]',
        'section'     => 'omag_single_post',
        'type'        => 'checkbox',
    )
);

/**===== Enable/Disable - Post Author in Single Post ======**/

$wp_customize->add_setting(
    'omag[single_post_author]', 
    array(
        'default'           => $default['single_post_author'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[single_post_author]', 
    array(
        'label'       => __('Enable Post Author', 'omag' ),    
        'settings'    => 'omag[single_post_author]',
        'section'     => 'omag_single_post',
        'type'        => 'checkbox',
    )
);

/**===== Enable/Disable - Post Category in Single Post =====**/

$wp_customize->add_setting(
    'omag[single_post_category]', 
    array(
        'default'           => $default['single_post_category'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[single_post_category]', 
    array(
        'label'       => __('Enable Post Category', 'omag' ),    
        'settings'    => 'omag[single_post_category]',
        'section'     => 'omag_single_post',
        'type'        => 'checkbox',
    )
);


/**===== Enable/Disable - Post Comments Count in Single Post =====**/

$wp_customize->add_setting(
    'omag[single_post_comments_count]', 
    array(
        'default'           => $default['single_post_comments_count'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[single_post_comments_count]', 
    array(
        'label'       => __('Enable Comments Count', 'omag' ),    
        'settings'    => 'omag[single_post_comments_count]',
        'section'     => 'omag_single_post',
        'type'        => 'checkbox',
    )
);

/**===== Enable/Disable - Post Tags in Single Post ======**/

$wp_customize->add_setting(
    'omag[single_post_tags]', 
    array(
        'default'           => $default['single_post_tags'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[single_post_tags]', 
    array(
        'label'       => __('Enable Post Tags', 'omag' ),    
        'settings'    => 'omag[single_post_tags]',
        'section'     => 'omag_single_post',
        'type'        => 'checkbox',
    )
);

/**====== Enable/Disable - Post Navigation =====**/

$wp_customize->add_setting(
    'omag[post_navigation]', 
    array(
        'default'           => $default['post_navigation'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[post_navigation]', 
    array(
        'label'       => __('Enable Previous/Next Post Navigation', 'omag' ),    
        'settings'    => 'omag[post_navigation]',
        'section'     => 'omag_single_post',
        'type'        => 'checkbox',
    )
);


/**====== Enable/Disable - Related Post ======**/

$wp_customize->add_setting(
    'omag[enable_related_posts]', 
    array(
        'default'           => $default['enable_related_posts'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_related_posts]', 
    array(
        'label'       => __('Enable Related Posts', 'omag' ),    
        'settings'    => 'omag[enable_related_posts]',
        'section'     => 'omag_single_post',
        'type'        => 'checkbox',
    )
);

/**===== Single Post Settings - End ======**/


/**====== General Setting - Start ======**/
$wp_customize->add_section(
    'omag_general', 
    array(    
        'title'       => __('General Settings', 'omag' ),
        'panel'       => 'omag_basic_panel'    
    )
);


/**===== Sidebar Options =======**/
$wp_customize->add_setting( 
    'omag[sidebar]',
    array(
        'default'           => $default['sidebar'],
        'sanitize_callback' => 'omag_sanitize_select',
    )
);
$wp_customize->add_control( 'omag[sidebar]',
    array(
        'label'       => esc_html__( 'Sidebar Options', 'omag'  ),
        'section'     => 'omag_general',   
        'settings'    => 'omag[sidebar]',
        'type'        => 'radio',
        'choices'     => array(
            'right'     => esc_html__( 'Right Sidebar', 'omag'  ),
            'left'      => esc_html__( 'Left Sidebar', 'omag'  ),
            )
    )
);

/**====== Pagination Style ========**/
$wp_customize->add_setting( 
    'omag[pagination_style]',
    array(
        'default'           => $default['pagination_style'],
        'sanitize_callback' => 'omag_sanitize_select',
    )
);
$wp_customize->add_control( 'omag[pagination_style]',
    array(
        'label'       => esc_html__( 'Pagination Style', 'omag'  ),
        'section'     => 'omag_general',   
        'settings'    => 'omag[pagination_style]',
        'type'        => 'radio',
        'choices'     => array(
            'default'     => esc_html__( 'Default', 'omag'  ),
            'numeric'      => esc_html__( 'Numeric', 'omag'  ),
            )
    )
);

/**===== Enable/Disable - Breadcrumb ========**/
$wp_customize->add_setting(
    'omag[enable_breadcrumb]', 
    array(
        'default'           => $default['enable_breadcrumb'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_breadcrumb]', 
    array(
        'label'       => __('Enable Breadcrumb', 'omag' ),    
        'settings'    => 'omag[enable_breadcrumb]',
        'section'     => 'omag_general',
        'type'        => 'checkbox',
    )
);

/**====== General Settings - End =====**/


/**====== Social Media Options - Start =====**/
$wp_customize->add_section(
    'omag_social', 
    array(    
        'title'       => __( 'Social Media', 'omag' ),
        'panel'       => 'omag_basic_panel'    
        ));

/*------ Social link -------*/
$social_options = array('facebook', 'twitter', 'google_plus', 'instagram', 'linkedin', 'pinterest', 'youtube', 'vimeo', 'flickr', 'behance', 'dribbble', 'tumblr', 'github' );

foreach($social_options as $social) {

    $social_name = ucwords(str_replace('_', ' ', $social));

    $label = '';

    switch ($social) {

        case 'facebook':
        $label = __('Facebook', 'omag' );
        break;

        case 'twitter':
        $label = __( 'Twitter', 'omag'  );
        break;

        case 'google_plus':
        $label = __( 'Google Plus', 'omag'  );
        break;

        case 'instagram':
        $label = __( 'Instagram', 'omag'  );
        break;

        case 'linkedin':
        $label = __( 'LinkedIn', 'omag'  );
        break;

        case 'pinterest':
        $label = __( 'Pinterest', 'omag'  );
        break;

        case 'youtube':
        $label = __( 'Youtube', 'omag'  );
        break;

        case 'vimeo':
        $label = __( 'vimeo', 'omag'  );
        break;

        case 'flickr':
        $label = __( 'Flickr', 'omag'  );
        break;

        case 'behance':
        $label = __( 'Behance', 'omag'  );
        break;

        case 'dribbble':
        $label = __( 'Dribbble', 'omag'  );
        break;

        case 'tumblr':
        $label = __( 'Tumblr', 'omag'  );
        break;

        case 'github':
        $label = __( 'Github', 'omag'  );
        break;

    }
    
    $wp_customize->add_setting( 'omag['.$social.']', array(
        'sanitize_callback'     => 'esc_url_raw',
        'sanitize_js_callback'  =>  'esc_url_raw'
        ));

    $wp_customize->add_control( 'omag['.$social.']', array(
        'label'     => $label,
        'type'      => 'text',
        'section'   => 'omag_social',
        'settings'  => 'omag['.$social.']'
        ));
}
/**====== Social Media Options - End ======**/


/**===== Footer Options - Start ======**/
$wp_customize->add_section(
    'omag_footer', 
    array(    
        'title'       => __( 'Footer', 'omag' ),
        'panel'       => 'omag_basic_panel'    
    )
);     

/**======= Copyright Text ======**/
$wp_customize->add_setting(
    'omag[copyright_text]', 
    array(
      'default'           => $default['copyright_text'],  
      'sanitize_callback' => 'sanitize_textarea_field',
    )
);

$wp_customize->add_control(
    'omag[copyright_text]', 
        array(
        'label'       => __( 'Copyright text', 'omag' ),    
        'settings'    => 'omag[copyright_text]',
        'section'     => 'omag_footer',
        'type'        => 'textarea'
    )
);

/**====== Enable/Disable - Footer Navigation ======**/ 
$wp_customize->add_setting(
    'omag[enable_footer_nav]',
    array(
        'default'           => $default['enable_footer_nav'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_footer_nav]', 
    array(
        'label'       => __( 'Enable Footer navigation', 'omag' ),    
        'settings'    => 'omag[enable_footer_nav]',
        'section'     => 'omag_footer',
        'type'        => 'checkbox',
    )
);

/**====== Enable/Disable - Scroll to Top =====**/
$wp_customize->add_setting(
    'omag[enable_scroll_top]', 
    array(
        'default'           => $default['enable_scroll_top'],     
        'sanitize_callback' => 'omag_sanitize_checkbox'
    )
);

$wp_customize->add_control(
    'omag[enable_scroll_top]', 
    array(
        'label'       => __( 'Enable scroll to top', 'omag' ),    
        'settings'    => 'omag[enable_scroll_top]',
        'section'     => 'omag_footer',
        'type'        => 'checkbox'
    )
);
/**======= Footer Options - end ======**/
