<?php 
/**
 * Sanitization
 *
 * @package OMag
 */

/**=========== Select/radio santitization ===========**/

if ( ! function_exists( 'omag_sanitize_select' ) ) :

    function omag_sanitize_select( $input, $setting ) {
      
        $input = esc_attr( $input );
      
        // Get list of choices from the control associated with the setting.
        $choices = $setting->manager->get_control( $setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

    }

endif;


/**=========== Checkbox santitization ===========**/

if ( ! function_exists( 'omag_sanitize_checkbox' ) ) :

    function omag_sanitize_checkbox( $input ) {

        if ( $input == 1 ) {

            return 1;

        } else {

            return '';

        }
    }

endif;


/**=========== Integer number sanitization ===========**/

if ( ! function_exists( 'omag_sanitize_number' ) ) :

    function omag_sanitize_number( $input, $setting ) {

        $input = absint( $input );

        return ( $input ? $input : $setting->default );

    }

endif;


/**=========== Active callback for top header ===========**/

if ( ! function_exists( 'omag_show_top_header' ) ) :

    function omag_show_top_header( $control ) { 

        if( 1 == $control->manager->get_setting( 'omag[enable_top_header]' )->value() ){

            return true;

        } else {

            return false;

        }
    }
 
endif;


/**=========== Active callback for hot news ===========**/

if ( ! function_exists( 'omag_show_hot_news' ) ) :

    function omag_show_hot_news( $control ) { 

        if( 1 == $control->manager->get_setting( 'omag[slider_enable]' )->value() ){

            return true;

        } else {

            return false;

        }
    }
 
endif;


/**=========== Active callback for slideshow ===========**/

if ( ! function_exists( 'omag_show_slideshow' ) ) :

    function omag_show_slideshow( $control ) { 

        if( 1 == $control->manager->get_setting( 'omag[slider_enable]' )->value() ){

            return true;

        } else {

            return false;

        }
    }
 
endif;


/**=========== Active callback for featured news ===========**/

if ( ! function_exists( 'omag_show_featured_news' ) ) :

    function omag_show_featured_news( $control ) { 

        if( 1 == $control->manager->get_setting( 'omag[featured_news_enable]' )->value() ){

            return true;

        } else {

            return false;

        }
    }
 
endif;


/**=========== Sanitize number range ===========**/

if ( ! function_exists( 'omag_sanitize_number_range' ) ) :
    
    function omag_sanitize_number_range( $input, $setting ) {

        // Ensure input is an absolute integer.
        $input = absint( $input );

        // Get the input attributes associated with the setting.
        $atts = $setting->manager->get_control( $setting->id )->input_attrs;

        // Get min.
        $min = ( isset( $atts['min'] ) ? $atts['min'] : $input );

        // Get max.
        $max = ( isset( $atts['max'] ) ? $atts['max'] : $input );

        // Get Step.
        $step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

        // If the input is within the valid range, return it; otherwise, return the default.
        return ( $min <= $input && $input <= $max && is_int( $input / $step ) ? $input : $setting->default );

    }

endif;
